@@ -1612,22 +1612,7 @@ class ClsClient(AbstractClient):
         此外日志服务还为用户提供以下两种不同的日志上传模式：
 
 
-        ## 请求
-
-        #### 请求头业务参数
-
-        X-CLS-HashKey 请求头表示日志根据 hashkey 路由写入到 CLS 对应范围的主题分区，以保证写入到的每个主题分区是严格有序的，便于消费时有序消费。
-
-        | 字段名             | 类型   | 位置   | 是否必须 | 含义                                                         |
-        | ------------------ | ------ | ------ | -------- | ------------------------------------------------------------ |
-        | X-CLS-HashKey      | string | header | 否       | 根据 hashkey 写入相应范围的主题分区                          |
-        | X-CLS-TopicId      | String | header | 是       | 主题id                                                       |                                                 |
-        | Content-Type       | String | header | 是       | 请求参数的协议类型， 目前只支持pb协议，填写 "application/octet-stream" |
-        | X-TC-Action        | String |	header | 是       | 公共参数，本接口取值：UploadLog。
-        | X-TC-Region        | String | header | 是   	  | 公共参数，本接口不需要传递此参数。
-        | X-TC-Version       | String | header | 是       | 公共参数，本接口取值：2020-10-16。
-
-        #### 输入参数（pb协议）
+        #### 输入参数(pb二进制流，位于body中)
 
         | 字段名       | 类型    | 位置 | 必须 | 含义                                                         |
         | ------------ | ------- | ---- | ---- | ------------------------------------------------------------ |
