@@ -26,6 +26,9 @@ FAILEDOPERATION_BLOCKBALANCE = 'FailedOperation.BlockBalance'
 # 数据操作失败。
 FAILEDOPERATION_DATAOPERATIONFAILED = 'FailedOperation.DataOperationFailed'
 
+# FailedOperation.DiskAttached
+FAILEDOPERATION_DISKATTACHED = 'FailedOperation.DiskAttached'
+
 # 镜像正在使用中。
 FAILEDOPERATION_IMAGEINUSE = 'FailedOperation.ImageInUse'
 
@@ -59,12 +62,24 @@ FAILEDOPERATION_PRIVATEIPADDRESSUNAVAILABLE = 'FailedOperation.PrivateIpAddressU
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# InternalError.ComponentError
+INTERNALERROR_COMPONENTERROR = 'InternalError.ComponentError'
+
+# InternalError.FailQueryResource
+INTERNALERROR_FAILQUERYRESOURCE = 'InternalError.FailQueryResource'
+
+# InternalError.ResourceOpFailed
+INTERNALERROR_RESOURCEOPFAILED = 'InternalError.ResourceOpFailed'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
 # 参数不支持同时指定。
 INVALIDPARAMETER_COEXIST = 'InvalidParameter.Coexist'
 
+# InvalidParameter.DiskConfigNotSupported
+INVALIDPARAMETER_DISKCONFIGNOTSUPPORTED = 'InvalidParameter.DiskConfigNotSupported'
+
 # 参数格式错误。
 INVALIDPARAMETER_FORMATERROR = 'InvalidParameter.FormatError'
 
@@ -89,6 +104,9 @@ INVALIDPARAMETER_PARAMETERCONFLICT = 'InvalidParameter.ParameterConflict'
 # 监听器端口检查失败，比如端口冲突。
 INVALIDPARAMETER_PORTCHECKFAILED = 'InvalidParameter.PortCheckFailed'
 
+# InvalidParameter.ProjectIdNotExist
+INVALIDPARAMETER_PROJECTIDNOTEXIST = 'InvalidParameter.ProjectIdNotExist'
+
 # 监听器协议检查失败，比如相关协议不支持对应操作。
 INVALIDPARAMETER_PROTOCOLCHECKFAILED = 'InvalidParameter.ProtocolCheckFailed'
 
@@ -125,12 +143,18 @@ INVALIDPARAMETERVALUE_IMAGESIZELARGETHANSYSDISKSIZE = 'InvalidParameterValue.Ima
 # 实例配置不匹配。
 INVALIDPARAMETERVALUE_INSTANCECONFIGNOTMATCH = 'InvalidParameterValue.InstanceConfigNotMatch'
 
+# 实例不支持当前操作。
+INVALIDPARAMETERVALUE_INSTANCEIDNOTSUPPORTED = 'InvalidParameterValue.InstanceIdNotSupported'
+
 # 实例名字长度超出限制。
 INVALIDPARAMETERVALUE_INSTANCENAMETOOLONG = 'InvalidParameterValue.InstanceNameTooLong'
 
 # 实例机型和pid不匹配。
 INVALIDPARAMETERVALUE_INSTANCETYPENOTMATCHPID = 'InvalidParameterValue.InstanceTypeNotMatchPid'
 
+# InvalidParameterValue.InsufficientRefundQuota
+INVALIDPARAMETERVALUE_INSUFFICIENTREFUNDQUOTA = 'InvalidParameterValue.InsufficientRefundQuota'
+
 # 无效的EIP。
 INVALIDPARAMETERVALUE_INVAILDADDRESSID = 'InvalidParameterValue.InvaildAddressId'
 
@@ -179,6 +203,15 @@ INVALIDPARAMETERVALUE_INVALIDDATADISKSIZE = 'InvalidParameterValue.InvalidDataDi
 # 数据盘类型不合法。
 INVALIDPARAMETERVALUE_INVALIDDATADISKTYPE = 'InvalidParameterValue.InvalidDataDiskType'
 
+# InvalidParameterValue.InvalidDisk
+INVALIDPARAMETERVALUE_INVALIDDISK = 'InvalidParameterValue.InvalidDisk'
+
+# InvalidParameterValue.InvalidDiskId
+INVALIDPARAMETERVALUE_INVALIDDISKID = 'InvalidParameterValue.InvalidDiskId'
+
+# InvalidParameterValue.InvalidDiskType
+INVALIDPARAMETERVALUE_INVALIDDISKTYPE = 'InvalidParameterValue.InvalidDiskType'
+
 # windows镜像不支持IP直通。
 INVALIDPARAMETERVALUE_INVALIDEIPDIRECTSERVICE = 'InvalidParameterValue.InvalidEIPDirectService'
 
@@ -212,6 +245,12 @@ INVALIDPARAMETERVALUE_INVALIDINSTANCETYPECONFIGID = 'InvalidParameterValue.Inval
 # 计费类型不合法。
 INVALIDPARAMETERVALUE_INVALIDINTERNETCHARGETYPE = 'InvalidParameterValue.InvalidInternetChargeType'
 
+# 秘钥ID无效。
+INVALIDPARAMETERVALUE_INVALIDKEYPAIRID = 'InvalidParameterValue.InvalidKeyPairId'
+
+# 秘钥名称异常。
+INVALIDPARAMETERVALUE_INVALIDKEYPAIRNAME = 'InvalidParameterValue.InvalidKeyPairName'
+
 # 负载均衡数量不合法。
 INVALIDPARAMETERVALUE_INVALIDLOADBALANCERNUM = 'InvalidParameterValue.InvalidLoadBalancerNum'
 
@@ -242,6 +281,12 @@ INVALIDPARAMETERVALUE_INVALIDREGION = 'InvalidParameterValue.InvalidRegion'
 # 全组ID不合法。
 INVALIDPARAMETERVALUE_INVALIDSECURITYGROUPID = 'InvalidParameterValue.InvalidSecurityGroupID'
 
+# InvalidParameterValue.InvalidSnapshot
+INVALIDPARAMETERVALUE_INVALIDSNAPSHOT = 'InvalidParameterValue.InvalidSnapshot'
+
+# InvalidParameterValue.InvalidSnapshotId
+INVALIDPARAMETERVALUE_INVALIDSNAPSHOTID = 'InvalidParameterValue.InvalidSnapshotId'
+
 # 系统盘大小不合法。
 INVALIDPARAMETERVALUE_INVALIDSYSTEMDISKSIZE = 'InvalidParameterValue.InvalidSystemDiskSize'
 
@@ -329,6 +374,9 @@ LIMITEXCEEDED_ADDRESSQUOTALIMITEXCEEDED = 'LimitExceeded.AddressQuotaLimitExceed
 # 申购次数不足，每个腾讯云账户每个地域每天申购次数为配额数*2 次。
 LIMITEXCEEDED_ADDRESSQUOTALIMITEXCEEDEDDAILYALLOCATE = 'LimitExceeded.AddressQuotaLimitExceededDailyAllocate'
 
+# LimitExceeded.AttachedDiskLimitExceeded
+LIMITEXCEEDED_ATTACHEDDISKLIMITEXCEEDED = 'LimitExceeded.AttachedDiskLimitExceeded'
+
 # 网卡配额不足。
 LIMITEXCEEDED_ENIQUOTALIMITEXCEEDED = 'LimitExceeded.EniQuotaLimitExceeded'
 
@@ -413,15 +461,48 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 实例不合法。
 RESOURCENOTFOUND_INSTANCENOTEXIST = 'ResourceNotFound.InstanceNotExist'
 
+# ResourceNotFound.NotFound
+RESOURCENOTFOUND_NOTFOUND = 'ResourceNotFound.NotFound'
+
+# ResourceUnavailable.Attached
+RESOURCEUNAVAILABLE_ATTACHED = 'ResourceUnavailable.Attached'
+
+# ResourceUnavailable.Expire
+RESOURCEUNAVAILABLE_EXPIRE = 'ResourceUnavailable.Expire'
+
 # 实例未运行。
 RESOURCEUNAVAILABLE_INSTANCENOTRUNNING = 'ResourceUnavailable.InstanceNotRunning'
 
+# ResourceUnavailable.NotPortable
+RESOURCEUNAVAILABLE_NOTPORTABLE = 'ResourceUnavailable.NotPortable'
+
+# ResourceUnavailable.NotSupported
+RESOURCEUNAVAILABLE_NOTSUPPORTED = 'ResourceUnavailable.NotSupported'
+
+# ResourceUnavailable.RepeatRefund
+RESOURCEUNAVAILABLE_REPEATREFUND = 'ResourceUnavailable.RepeatRefund'
+
+# ResourceUnavailable.TypeError
+RESOURCEUNAVAILABLE_TYPEERROR = 'ResourceUnavailable.TypeError'
+
 # 负载均衡资源已经售罄。
 RESOURCESSOLDOUT_LOADBALANCERSOLDOUT = 'ResourcesSoldOut.LoadBalancerSoldOut'
 
+# 未授权操作。
+UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
+
 # 没有权限进行该操作。
 UNAUTHORIZEDOPERATION_FORBIDDENOPERATION = 'UnauthorizedOperation.ForbiddenOperation'
 
+# UnauthorizedOperation.MFAExpired
+UNAUTHORIZEDOPERATION_MFAEXPIRED = 'UnauthorizedOperation.MFAExpired'
+
+# UnauthorizedOperation.NotCertification
+UNAUTHORIZEDOPERATION_NOTCERTIFICATION = 'UnauthorizedOperation.NotCertification'
+
+# UnauthorizedOperation.NotHavePaymentRight
+UNAUTHORIZEDOPERATION_NOTHAVEPAYMENTRIGHT = 'UnauthorizedOperation.NotHavePaymentRight'
+
 # 无windows镜像权限。
 UNAUTHORIZEDOPERATION_WINDOWSIMAGE = 'UnauthorizedOperation.WindowsImage'
 
@@ -488,6 +569,12 @@ UNSUPPORTEDOPERATION_MUTEXOPERATIONTASKRUNNING = 'UnsupportedOperation.MutexOper
 # 实例规格仅支持绑定三个EIP。
 UNSUPPORTEDOPERATION_QUOTALIMITEXCEEDED = 'UnsupportedOperation.QuotaLimitExceeded'
 
+# UnsupportedOperation.SnapHasShared
+UNSUPPORTEDOPERATION_SNAPHASSHARED = 'UnsupportedOperation.SnapHasShared'
+
+# UnsupportedOperation.SnapshotHasBindedImage
+UNSUPPORTEDOPERATION_SNAPSHOTHASBINDEDIMAGE = 'UnsupportedOperation.SnapshotHasBindedImage'
+
 # 当前状态不能进行此操作。
 UNSUPPORTEDOPERATION_STATUSNOTPERMIT = 'UnsupportedOperation.StatusNotPermit'
 
